You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@allura.apache.org by di...@apache.org on 2022/11/02 20:49:35 UTC

[allura] 05/07: [#8455] update docker test run to use pytest

This is an automated email from the ASF dual-hosted git repository.

dill0wn pushed a commit to branch pytest-finalize
in repository https://gitbox.apache.org/repos/asf/allura.git

commit be65c00db958de688bc540ac3a2dc02e46e95fe2
Author: Dillon Walls <di...@slashdotmedia.com>
AuthorDate: Tue Nov 1 15:30:49 2022 +0000

    [#8455] update docker test run to use pytest
---
 scripts/jenkins-python3.7.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/scripts/jenkins-python3.7.sh b/scripts/jenkins-python3.7.sh
index 3746742a8..d8f5baa67 100755
--- a/scripts/jenkins-python3.7.sh
+++ b/scripts/jenkins-python3.7.sh
@@ -42,7 +42,7 @@ echo "==========================================================================
 echo "Run: cleanup previous runs"
 echo "============================================================================="
 rm -rf ./allura-data
-git clean -f -x  # remove test.log, nosetest.xml etc (don't use -d since it'd remove our venv dir)
+git clean -f -x  # remove test.log, pytest.junit.xml etc (don't use -d since it'd remove our venv dir)
 
 docker-compose down
 
@@ -98,7 +98,7 @@ docker-compose exec -T web bash -c "pyflakes Allura* Forge* scripts | awk -F\: '
 docker-compose exec -T web bash -c "pycodestyle Allura* Forge* scripts > pep8.txt"
 
 # TODO: ALLURA_VALIDATION=all
-docker-compose exec -T -e LANG=en_US.UTF-8 web ./run_tests --with-xunitmp # --with-coverage --cover-erase
+docker-compose exec -T -e LANG=en_US.UTF-8 web ./run_tests --junit-xml=pytest.junit.xml # --with-coverage --cover-erase
 retcode=$?
 
 #find . -name .coverage -maxdepth 2 | while read coveragefile; do pushd `dirname $coveragefile`; coverage xml --include='forge*,allura*'; popd; done;